# Nisaba 0.2.7
A tool for multi-modal annotation

## Most Recent Update

### v.0.2.7

+ Package hierarchy and files for PyPi releases

[Full Change Log](changelog.md)

## Development History
Conceived by [M. H. Beals](https://github.com/mhbeals) (Loughborough University) and Olivia Mitchell (Loughborough University)  
Initial Development (0.1.0) by [M. H. Beals](https://github.com/mhbeals)  
Continuing Development by [M. H. Beals](https://github.com/mhbeals) and [Albert Meroño Peñuela](https://github.com/albertmeronyo) (Vrije Universiteit Amsterdam)  

## Dependencies
- [rdflib](https://github.com/RDFLib/rdflib)
- [ttkwidgets](https://github.com/RedFantom/ttkwidgets)
